@@ -1,4 +1,5 @@
-from discord.ext.commands import Bot
+from typing import Union
+from discord.ext.commands import Bot, AutoShardedBot
 
 
 class Global:
@@ -8,7 +9,7 @@ class Global:
 
 class Bots:
 
-    def __init__(self, bot: Bot, token):
+    def __init__(self, bot: Union[Bot, AutoShardedBot], token: str):
         if not token.startswith("SDC "):
             token = "SDC " + token
         self.SDC_token = token
@@ -27,4 +28,4 @@ class Bots:
         except Exception as e:
             print(e)
         else:
-            print(f"SDC_API: Цикл успешно запущен. Статистика будет обновляться каждые {Global._time} минут")
\ No newline at end of file
+            print(f"SDC: Цикл успешно запущен. Статистика будет обновляться каждые {Global._time} минут")
\ No newline at end of file
